import requests
from rickandmorty.base  import Base

class Locations(Base):
    def getAll(self):
        """
            Args: No arg necessary

            Returns: All location information in the json
        """
        response = requests.get(self.url+'location/')
        return response.json()
    def getSingle(self, location_order):
        """
            Args: Only one  int value between 1-108.

            Returns: The properties of the given number's defined location.
        """
        response = requests.get(self.url+'location/{}'.format(location_order))
        return response.json()
    def getMultiple(self, *orders):
        """
            Args: int values between 1-108

            Returns: The properties of the given numbers' defined locations.
        """
        y = list(orders)
        response = requests.get(self.url+'location/{}'.format(y))
        return response.json()
    def filter(self, name = '', type='', dimension =''):
        """
            Args: name =filter by the given name.\n
            type=filter by the given type.\n
            dimension=filter by the given dimension.\n

            Returns: Locations matching the given values.
        """
        payload = {'name': name ,  'type': type, 'dimension': dimension}
        response = requests.get(self.url+'location/', params=payload)
        return response.json()



import requests
from rickandmorty.base  import Base

class Characters(Base):

    def getAll(self):
        """
            Args: No arg necessary

            Returns: All character information in the json format.
        """
        response = requests.get(self.url+'character/')
        return  response.json()
    def getSingle(self,character_order):
        """
            Args: Only one  int value between 1-671

            Returns: The properties of the given number's defined character.
        """
        response = requests.get(self.url +'character/{}'.format(character_order))
        return response.json()
    def getMultiple(self, *orders):
        """
            Args: int values between 1-671

            Returns: The properties of the given numbers' defined characters.
        """
        y=list(orders)
        response = requests.get(self.url+'character/{}'.format(y))
        return response.json()
    def filter(self, name='',status='',species='',type='', gender=''):
        """
            Args: name =filter by the given name.\n
            status=filter by the given status  (alive , dead , unknown),\n
            species=filter by the given species(Human...),\n
            type= filter by the given type,\n
            gender=filter by the given gender(male ,female,genderless,unknown)\n

            Returns: Characters matching the given values.
        """
        payload ={'name':name , 'status':status , 'species':species , 'type':type ,'gender':gender }
        response = requests.get(self.url+'character', params=payload)
        return response.json()




import requests
from rickandmorty.base  import Base

class Episodes(Base):
    def getAll(self):
        """
            Args: No arg necessary

            Returns: All episodes information in the json.
        """
        response = requests.get(self.url+'episode/')
        return response.json()
    def getSingle(self, episode):
        """
            Args: Only one  int value between 1-42.

            Returns: The properties of the given number's defined episode.
        """
        response = requests.get(self.url+'episode/{}'.format(episode))
        return response.json()
    def getMultiple(self, *episodes):
        """
            Args: int values between 1-42

            Returns: The properties of the given numbers' defined episodes.
        """
        y = list(episodes)
        response = requests.get(self.url+'episode/{}'.format(y))
        return response.json()
    def filter(self , name='', episode=''):
        """
            Args: name =filter by the given name.\n
            episode=filter by the given episode code.\n

            Returns: Episodes matching the given values.
        """
        payload = {'name': name, 'episode': episode}
        response = requests.get(self.url+'episode/', params=payload)
        return response.json()


from setuptools import find_packages, setup

with open('README.md') as readme_file:
    readme = readme_file.read()

setup(
    name='rickandmorty',
    author='Dogukan Baloglu',
    author_email='dogukanbaloglu99@gmail.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=find_packages(include=['rickandmorty'],exclude=['tests*']),
    version='0.1.0',
    description='Rick and Morty client for Rick and Morty API (https://rickandmortyapi.com/) ',
    long_description= readme ,
    long_description_content_type='text/markdown',
    license='MIT License',
    install_requires=['requests'],
    test_require=[''],
    keywords='rickandmorty',
    url='https://github.com/DogukanBaloglu/rickandmorty'
)